@@ -1,47 +1,18 @@
 package File::Spec;
 
-require Exporter;
-
-@ISA = qw(Exporter);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	
-);
-@EXPORT_OK = qw($Verbose);
-
 use strict;
-use vars qw(@ISA $VERSION $Verbose);
+use vars qw(@ISA $VERSION);
 
-$VERSION = '0.7';
+$VERSION = '0.81';
 
-$Verbose = 0;
+my %module = (MacOS   => 'Mac',
+	      MSWin32 => 'Win32',
+	      os2     => 'OS2',
+	      VMS     => 'VMS');
 
-require File::Spec::Unix;
-
-
-sub load {
-	my($class,$OS) = @_;
-	if ($OS eq 'VMS') {
-		require File::Spec::VMS;
-		require VMS::Filespec;
-		'File::Spec::VMS'
-	} elsif ($OS eq 'os2') {
-		require File::Spec::OS2;
-		'File::Spec::OS2'
-	} elsif ($OS eq 'MacOS') {
-		require File::Spec::Mac;
-		'File::Spec::Mac'
-	} elsif ($OS eq 'MSWin32') {
-		require File::Spec::Win32;
-		'File::Spec::Win32'
-	} else {
-		'File::Spec::Unix'
-	}
-}
-
-@ISA = load('File::Spec', $^O);
+my $module = $module{$^O} || 'Unix';
+require "File/Spec/$module.pm";
+@ISA = ("File::Spec::$module");
 
 1;
 __END__
@@ -59,7 +30,7 @@ File::Spec - portably perform operations on file names
 which returns 'a/b/c' under Unix. Or:
 
 	use File::Spec::Functions;
-	
+
 	$x = catfile('a', 'b', 'c');
 
 =head1 DESCRIPTION
@@ -82,28 +53,23 @@ OS specific routines is available in a separate module, including:
 	File::Spec::VMS
 
 The module appropriate for the current OS is automatically loaded by
-File::Spec. Since some modules (like VMS) make use of facilities only under
-that OS, it may not be possible to load all modules under all operating
-systems.
+File::Spec. Since some modules (like VMS) make use of facilities available
+only under that OS, it may not be possible to load all modules under all
+operating systems.
 
 Since File::Spec is object oriented, subroutines should not called directly,
 as in:
 
 	File::Spec::catfile('a','b');
-	
+
 but rather as class methods:
 
 	File::Spec->catfile('a','b');
 
-Alternatively, File::Spec::Functions can be used instead, which exports
-functions for all of the class methods provided by File::Spec, including
-catfile, so you may say:
+For simple uses, L<File::Spec::Functions> provides convenient functional
+forms of these methods.
 
-	use File::Spec::Functions;
-	
-	catfile('a','b');
-
-For a reference of available functions, pleaes consult L<File::Spec::Unix>,
+For a list of available methods, please consult L<File::Spec::Unix>,
 which contains the entire set, and which is inherited by the modules for
 other platforms. For further information, please see L<File::Spec::Mac>,
 L<File::Spec::OS2>, L<File::Spec::Win32>, or L<File::Spec::VMS>.
@@ -111,7 +77,7 @@ L<File::Spec::OS2>, L<File::Spec::Win32>, or L<File::Spec::VMS>.
 =head1 SEE ALSO
 
 File::Spec::Unix, File::Spec::Mac, File::Spec::OS2, File::Spec::Win32,
-File::Spec::VMS, ExtUtils::MakeMaker
+File::Spec::VMS, File::Spec::Functions, ExtUtils::MakeMaker
 
 =head1 AUTHORS
 
@@ -120,9 +86,7 @@ Kenneth Albanowski <F<kjahds@kjahds.com>>, Andy Dougherty
 <F<A.Koenig@franz.ww.TU-Berlin.DE>>, Tim Bunce <F<Tim.Bunce@ig.co.uk>>. VMS
 support by Charles Bailey <F<bailey@newman.upenn.edu>>.  OS/2 support by
 Ilya Zakharevich <F<ilya@math.ohio-state.edu>>. Mac support by Paul Schinder
-<F<schinder@pobox.com>>.
-
-=cut
-
-
-1;
+<F<schinder@pobox.com>>.  abs2rel() and rel2abs() written by
+Shigio Yamaguchi <F<shigio@tamacom.com>>, modified by Barrie Slaymaker
+<F<barries@slaysys.com>>.  splitpath(), splitdir(), catpath() and catdir()
+by Barrie Slaymaker.
